@@ -22,32 +22,32 @@ from functions_record import *
 ###########################################################################
 ## Function to open or close the log file
 ###########################################################################
-def CreateRecordFile(interval):       
-    #if not on the N900, use another place for the log file 
+def CreateRecordFile(interval):
+    #if not on the N900, use another place for the log file
     if(data.demo==True): data.logfolder=data.devlogfolder #folder on devel PC
     else: data.logfolder=data.defaultlogfolder
-    
+
     print "Logfolder:",  data.logfolder
     if(not os.path.exists(data.logfolder)): #create log folder
         try:
             os.mkdir(data.logfolder)
         except:
             print "Failed to create logfolder!"
-            
+
     if(data.debug==1): PrintRecordData()
-        
-    
+
+
     #create file, write header
     d=strftime("%Y-%m-%d_%H-%M-%S", records.StartTime_tuple)
     data.logfilename="SleepAnalyser_"+d+".csv"
     data.logfile = open(data.logfolder+data.logfilename, 'w')
     print "Created logfile "+data.logfilename
-    
+
     h=CreateHeader()
     data.logfile.write(h)
     data.logfile.flush()
-    
-    
+
+
 
 
 
@@ -56,19 +56,20 @@ def CreateRecordFile(interval):
 
 
 ###########################################################################
-## 
+##
 ###########################################################################
 def CreateHeader():
-    if(records.SWversion<1.6): records.SWversion=1.6 #update file version sas header gets saved in new version
+    if(records.SWversion<1.8): records.SWversion=1.8 #update file version as header gets saved in new version
+                                                                                    #This value should be updated every time a file structure change happens!
     h=" , , , User: " + str(records.User.encode( "utf-8" ))+ \
         ", SW version: " + str(records.SWversion)+ \
         ", Sampling interval: " + str(records.Sampling_interval)+ \
         ", Sample smoothing: " + str(records.Sample_smoothing)+ \
         ", Value smoothing: " + str(records.Value_smoothing) + \
-        ", Trigger level: " + str(records.Trigger) 
-        
+        ", Trigger level: " + str(records.Trigger)
+
     h=h+"\n"+"Start time: "+strftime(data.dateformat,  records.StartTime_tuple)
-            
+
     if(records.AlarmIsSet==True):
         if(records.AlarmTime_tuple!=-1):
             h=h+"\n"+"Alarm: "+strftime(data.dateformat,records.AlarmTime_tuple)
@@ -80,11 +81,11 @@ def CreateHeader():
         h=h+"\n"+"No alarm set"
         h=h+"\n"+"Alarm Time Window Start: Not set"
         h=h+"\n"+"Alarm Time Window End: Not set"
-    
+
     h=h+"\n"+"Note: "+str(records.Note.encode( "utf-8" ))
-    
-    h=h+"\n"+"Time, AccX, AccY, Event:\n"
-    
+
+    h=h+"\n"+"Time,   AccX, AccY, AccY:\n"
+
 #    print "Record header:\n"+h+"\n"
     if(data.debug==1): print "##############################\nHeader:\n"+h+"\n##############################"
     return h
@@ -95,19 +96,20 @@ def CreateHeader():
 ###########################################################################
 ##  Write data into file, so it can be used in other tools
 ###########################################################################
-def WriteIntoRecordFile():
-        
+def WriteRecord():
+
     d=str(records.arrData[0][records.Index-1]) + ", " +  \
         str(records.arrData[1][records.Index-1]) + ", " +  \
         str(records.arrData[2][records.Index-1]) + ", " +  \
+        str(records.arrData[3][records.Index-1]) + ", " +  \
         str(records.arrData[5][records.Index-1])
 
     data.logfile.write(d+"\n")
 #    if(data.debug==1): print "Write to file:",d
 
-    if(records.Index % 30 == 0): 
+    if(records.Index % 30 == 0):
         if(data.debug==1): print "Flush data from IO buffer into file"
-        data.logfile.flush() #Every 30 indices (5 minutes in normal mode), write data into file from IO buffer
+        data.logfile.flush() #Every 30 indices (5 minutes in normal mode), write data from IO buffer into file
 
 
 
@@ -115,12 +117,12 @@ def WriteIntoRecordFile():
 ###########################################################################
 ##  Close log file
 ###########################################################################
-def StopLogfile():    
-    if(records.AlarmIsSet==True): 
+def StopLogfile():
+    if(records.AlarmIsSet==True):
         records.LastIndex=max(records.Index,  Tuple2Index(records.AlarmTimeWindowEnd_tuple)+5) #the very last index to be shown (incl. AlarmTimeWindowEnd
     else: records.LastIndex=records.Index
     data.logfile.close()
-    
+
 
 
 
@@ -138,7 +140,7 @@ def LoadFileList():
         data.arrLogFileIndex=0
         for i in range(len(data.arrLogFiles)):
             if(data.logfilename==data.arrLogFiles[i]): data.arrLogFileIndex=i
-            
+
     if(data.debug==1): print "LoadFileList,  Index:",  data.arrLogFileIndex
 
 
@@ -147,19 +149,19 @@ def LoadFileList():
 ###########################################################################
 ##  Load log file  to read and visualise it
 ###########################################################################
-def LoadRecord():    
+def LoadRecord():
     InitRecord() #clear all old data
-        
+
     data.logfolder=string.replace(data.logfolder, "~",  data.homedir) #workaround
-    print "Open Log file:",  data.logfolder+data.logfilename,  "to load data..."    
+    print "Open Log file:",  data.logfolder+data.logfilename,  "to load data..."
     if(not os.path.exists(data.logfolder)): #create log folder (dirty workaround for if folder is not existing
         os.mkdir(data.logfolder)
         data.lastlogfile=""
     f=data.logfolder+data.logfilename
-    if(not os.path.exists(f) or data.logfilename==""): return 2 #selected file or folder does not exist 
-    
-    file = open(f, 'r')    
-    
+    if(not os.path.exists(f) or data.logfilename==""): return 2 #selected file or folder does not exist
+
+    file = open(f, 'r')
+
     try: #read header data
        #process header line 1
         tmp=file.readline()
@@ -172,7 +174,7 @@ def LoadRecord():
     #            records.status="File version not compatible"
     #            records.statusID="VERSION_INCOMPATIBLE"
     #            file.close()
-    #            return 9    
+    #            return 9
             records.User=string.replace(header[3].decode("utf-8") , "User:",  "")
             Startdate_date=string.replace(header[5], "Date:",  "")
             x=string.replace(header[6], "Sampling interval:",  "")
@@ -192,7 +194,7 @@ def LoadRecord():
         elif(records.SWversion<1.6): #workaround for old files
             #process header line 2
             tmp=file.readline()
-            records.Note=string.replace(tmp[:-1].decode("utf-8"), "Note: ",  "")    
+            records.Note=string.replace(tmp[:-1].decode("utf-8"), "Note: ",  "")
         else:
            #process header line 2
             tmp=file.readline()
@@ -200,7 +202,7 @@ def LoadRecord():
             tmp=string.replace(tmp[:-1], "Start time: ",  "")
             records.StartTime_tuple=time.strptime(tmp,  data.dateformat)
             records.StartTime_seconds=Tuple2Seconds( records.StartTime_tuple)
-                
+
            #process header line 3
             tmp=file.readline()
     #        print tmp
@@ -212,45 +214,45 @@ def LoadRecord():
                 records.AlarmTime_seconds=Tuple2Seconds( records.AlarmTime_tuple)
             else:
                 if(data.debug==1): print "No alarm is set"
-            
+
            #process header line 4
             tmp=file.readline()
     #        print tmp
-#            if(records.AlarmIsSet==True): 
+#            if(records.AlarmIsSet==True):
             tmp=string.replace(tmp[:-1], "Alarm Time Window Start: ",  "")
             if(tmp!="Not set"):
                 records.AlarmTimeWindowStart_tuple=time.strptime(tmp,  data.dateformat)
                 records.AlarmTimeWindowStart_seconds=Tuple2Seconds(records.AlarmTimeWindowStart_tuple)
-            
+
            #process header line 5
             tmp=file.readline()
     #        print tmp
-#            if(records.AlarmIsSet==True): 
+#            if(records.AlarmIsSet==True):
             tmp=string.replace(tmp[:-1], "Alarm Time Window End: ",  "")
             if(tmp!="Not set"):
                 records.AlarmTimeWindowEnd_tuple=time.strptime(tmp,  data.dateformat)
                 records.AlarmTimeWindowEnd_seconds=Tuple2Seconds( records.AlarmTimeWindowEnd_tuple)
                 records.AlarmTimeWindow_minutes=int((records.AlarmTimeWindowEnd_seconds-records.AlarmTimeWindowStart_seconds)/60)
                 if(records.AlarmTimeWindowStart_tuple!=-1): records.AlarmIsSet=True
-            
+
            #process header line 6
             tmp=file.readline()
             records.Note=string.replace(tmp[:-1].decode("utf-8"), "Note: ",  "")
-            
+
           #process header line 7
             tmp=file.readline()  #not used, column header
-        
+
 
         print "Record header successful read"
     except:
         print "Record header data corrupt"
         records.status="File header corrupted or not compatible"
         records.statusID="HEADER_CORRUPTED"
-#        print sys.exc_info() 
+#        print sys.exc_info()
         file.close()
         return 8
-    
-    
+
+
 
     records.Index=0
     try: #get data
@@ -261,14 +263,21 @@ def LoadRecord():
             records.arrData[0][records.Index]=d[0] #time
             records.arrData[1][records.Index]=int(d[1]) #X
             records.arrData[2][records.Index]=int(d[2]) #Y
-            try:
+            if(records.SWversion<1.8): #workaround for old files (versions <1.8 had only X and Y axis stored)
+                records.arrData[3][records.Index]=0 #Z
                 records.arrData[5][records.Index]=d[3] #Event
-            except:
-                pass
-    #           
-            records.Index=records.Index+1            
-            if(records.Index==records.MaxArrayDataLen-1): 
-                print "Stopped, array is full, file is to big. Loaded ",  records.Index,  "lines"                
+            else:
+                records.arrData[3][records.Index]=int(d[3]) #Z
+                records.arrData[5][records.Index]=d[4] #Event
+
+#            try:
+#                records.arrData[5][records.Index]=d[3] #Event
+#            except:
+#                pass
+    #
+            records.Index=records.Index+1
+            if(records.Index==records.MaxArrayDataLen-1):
+                print "Stopped, array is full, file is to big. Loaded ",  records.Index,  "lines"
                 records.status="Data Array is full (max "+str(records.MaxArrayDataLen)+ " entries)"
                 records.statusID="ARRAY_FULL"
     #                file.close()
@@ -282,45 +291,45 @@ def LoadRecord():
         return 3 #corrupted file
     finally:
         file.close()
-        
+
     if(records.Index==0):
         print "No movement data in record"
         records.status="No movement data in file to be shown"
         records.statusID="NO_DATA"
         return 4
-        
-        
+
+
     if(records.SWversion<1.6): #workaround for old files
         if(records.Index>0): records.StartTime_tuple=time.strptime(Startdate_date+" "+str(records.arrData[0][0]),  " %d-%m-%Y %H:%M:%S") #no data anyway
         else: records.StartTime_tuple=time.strptime(Startdate_date+" 00:00:00",  " %d-%m-%Y %H:%M:%S") #no data anyway
         records.StartTime_seconds=Tuple2Seconds(records.StartTime_tuple)
-        
+
     #calculate end time
     records.EndTime_seconds=Tuple2Seconds(records.StartTime_tuple)+records.Index*records.Sampling_interval*records.Value_smoothing/1000
     records.EndTime_tuple=Seconds2Tuple(records.EndTime_seconds)
 
     print "Loaded successful",  records.Index, "lines"
-    if(records.AlarmIsSet==True): 
+    if(records.AlarmIsSet==True):
         records.LastIndex=max(records.Index,  Tuple2Index(records.AlarmTimeWindowEnd_tuple)+5) #the very last index to be shown (incl. AlarmTimeWindowEnd
         if(data.debug==1): print "But will show up to index",  records.LastIndex,  "as the AlarmTimeWindow ends there"
     else: records.LastIndex=records.Index
-        
+
     records.status="Data successful loaded"
     records.statusID="OK"
-    
+
     if(data.debug==1): PrintRecordData(False)
     return 0 #all ok
-    
-    
-    
-    
-    
-    
-    
+
+
+
+
+
+
+
 ###########################################################################
-##  
+##
 ###########################################################################
-def UpdateFileHeader():    
+def UpdateFileHeader():
 #    print "Reopen log file and update note:",  records.Note
     file = open(data.logfolder+data.logfilename, 'w')
     print "Update header in logfile",  data.logfilename
@@ -329,9 +338,9 @@ def UpdateFileHeader():
     file.write(h)
     i=0
     for i in range(0,  records.Index):
-        d=str(records.arrData[0][i]) + ", " + str(records.arrData[1][i]) + ", " +  str(records.arrData[2][i]) + ", " +  str(records.arrData[5][i])
+        d=str(records.arrData[0][i]) + ", " + str(records.arrData[1][i]) + ", " +  str(records.arrData[2][i]) + \
+            ", " +  str(records.arrData[3][i]) + ", " +  str(records.arrData[5][i])
         file.write(d+"\n")
     file.close()
     if(data.debug==1): print "Wrote",  i +1,  "records into file"
-    
-    
+
