@@ -124,52 +124,23 @@ def ProcessData(ProcessAll=False, ShowFiltered=False):  #DERIVATION (ABLEITUNG)
             Zder=0
             XYZderivation=0
 #        records.arrData[4][i]=min(XYZderivation*data.Yscale,  data.Ysize-17) #cut off if higher than graph border
-        records.arrData[4][i]=XYZderivation
+        records.arrData[4][i]=abs(XYZderivation-data.derivation_offset)
 
 
 
 
 
 def FilterData():
-
-###        mylib.sleep_filter()
-##        if(data.debug==1): print "Filter array:"
-##        if(data.debug==1): print data.arrFilter
-##        l=len(data.arrFilter)
-##        if(data.debug==1): print "Lenght:",  l
-##
         Xscale=data.arrXscale[data.Xscale]
-##
-##        for i in range(0,  records.Index-data.Derivation,  Xscale): #loop arrData
-##            value=records.arrData[4][i]
-##            if((i%500)==0):
-##                Progress="Filter data ("+ str(i*100/(records.Index-data.Derivation)) +"%)..."
-#        self.ui.lblStatus.setText("Apply filter")
-#        app.processEvents() #force ui update
-##            for p in range(0,  l-1): #loop arrFilter
-##                records.arrData[6][i+p-data.FilterShift] = records.arrData[6][i+p-data.FilterShift] + value*data.arrFilter[p]
-##
-##        for i in range(0,  records.Index,  Xscale): #scalling
-##            records.arrData[6][i]  = records.arrData[6][i] / data.FilterScale*Xscale
-##            if(records.arrData[6][i] >data.Ysize):
-##                records.arrData[6][i]  = int(random.uniform(data.Ysize-9,data.Ysize-15))
-
-#        a=mylib.sleep_filter()
-#        print a
-
-#        print "##### mylib is compiled:", mylib.IsCompiled()
 
         arrSend=[0]*(records.Index+len(data.arrFilter))
         for i in range(0,  records.Index-data.Derivation): #copy array
             arrSend[i]=records.arrData[4][i]
 
-#        for i in range(0,  50): print arrSend[i],  records.arrData[4][i]
-
-        arrRet=mylib.sleep_filter(arrSend, records.Index-data.Derivation, data.arrFilter, data.FilterShift)
+        arrRet=mylib.sleep_filter(arrSend, records.Index-data.Derivation, data.arrFilter, data.FilterShift, 61-data.filterScale)
 #        print arrRet
-
         for i in range(0,  records.Index-data.Derivation): #copy array and scale
-            records.arrData[6][i]  = arrRet[i] / data.FilterScale
+            records.arrData[6][i]  = arrRet[i]
             if(records.arrData[6][i] > data.Ysize-7):
                 records.arrData[6][i]  = data.Ysize-7 #-int(random.uniform(1, 2))
             elif(records.arrData[6][i] < 13): records.arrData[6][i] =13
@@ -421,7 +392,7 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
 
 
 
-        #DRAW Filtered graph
+        #DRAW sleep graph
         if(ShowFiltered==True):  #only show in view window, not during recording
             pen=QtGui.QPen()
 
@@ -845,4 +816,3 @@ def PrintRecordData(ShowArray=True):
 
 
 
-
