@@ -58,6 +58,7 @@ else: data.app_path=data.app_path+"/"
 #load language file
 import i18n
 _ = i18n.language.gettext
+#print _("Special character test: (*** INSERT SOME SPECIAL CHARACTERS IN YOUR LANGUAGE TO TEST THE TRANSLATION. IT WILL BE SHOWN IN THE TERMINAL ***)")
 
 
 
@@ -123,11 +124,6 @@ def main():
 #        print "changed default parameters for Yscale and Ysize"
 
 
-
-    print _("Hello World")
-    print _("Line 1\nLine 2")
-
-
     #Load version file
     try:
         if(data.debug==1): print "Application path:",  data.app_path
@@ -271,9 +267,10 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
             GenerateGraphBitmap(RecordWindow, False)
 
         if(records.Index==records.MaxArrayDataLen-1):
-            print "Stopped, array is full"
-            data.Status=_("Stopped, array is full!")
-            QtGui.QMessageBox.warning(RecordWindow, _('Memory is full!'), _("You reached the end of the recording capacity!\nThe recording stops now."), QtGui.QMessageBox.Ok)
+            txt=_('Memory is full!')
+            print txt
+            data.Status=txt
+            QtGui.QMessageBox.warning(RecordWindow, txt, _("You reached the end of the recording capacity!\nThe recording stops now."), QtGui.QMessageBox.Ok)
 #            RecordWindow.StopMeasurement()
             StopMeasurement() #stop but keep alarm active!
 
@@ -486,10 +483,11 @@ def MoveTrigger(direction):
 
 
 def About(ui):
-    QtGui.QMessageBox.about(ui, 'About SleepAnalyser', "Copyright 2010 by George Ruinelli with great support from the MAEMO community\n"+\
-    "Version: "+str(data.version)+"-"+str(data.build)+"\n"+\
-    "Contact: george@ruinelli.ch\nWebsite: https://garage.maemo.org/projects/sleepanalyser/\n"+\
-    "\nFeedback and donations are very welcome!")
+    QtGui.QMessageBox.about(ui, _("About")+" SleepAnalyser", _("Copyright 2010 by George Ruinelli with great support from the MAEMO community\n")+\
+    _("Version:")+" "+str(data.version)+"-"+str(data.build)+"\n"+\
+    _("Contact:")+" george@ruinelli.ch\n" +\
+    _("Website:")+" http://www.ruinelli.ch/sleepanalyser/\n\n"+\
+    _("Feedback and donations are very welcome!"))
 
 
 
@@ -549,18 +547,17 @@ class frmStartWindow(QMainWindow):
 
 
         #set texts
-#        StartWindow.setWindowTitle("SleepAnalyser")
+        self.setWindowTitle("SleepAnalyser")
         self.ui.bLog.setText(_("View records"))
         self.ui.bCollecting.setText(_("Start recording only"))
-        self.ui.bSetAlarm.setText(_("Set alarm and\n"
-                                                "start recording"))
-        self.ui.lblNote.setText(_("Development version, might be unstable!"))
+        self.ui.bSetAlarm.setText(_("Set alarm and\nstart recording"))
         self.ui.menuMenu.setTitle(_("Menu"))
         self.ui.actionAbout.setText(_("About"))
         self.ui.actionSettings.setText(_("Settings"))
         self.ui.actionHelp.setText(_("Help"))
         self.ui.actionTest_recording.setText(_("Test recording"))
 
+        self.ui.lblNote.setText(_("Development version, might be unstable!"))
 
 
 
@@ -753,8 +750,17 @@ class frmRecordWindow(QMainWindow):
             self.ui.bLowerTrigger.setIcon(QIcon(data.app_path+"img/"+"go-down.png"))
             self.ui.bEditNote.setIcon(QIcon(data.app_path+"img/"+"kwrite.png"))
 
+        self.setWindowTitle("SleepAnalyser ("+_("Recording")+")")
+        self.ui.lblElapsedTime.setText(_("Elapsed time:")+" 0")
+        self.ui.bStop.setText(_("Stop"))
+        self.ui.lblAlarmTime.setText(_("Alarm time: (not set)"))
+        self.ui.lblStatus2.setText(_("Status:"))
+        self.ui.lblStatus.setText(_("Loading..."))
+        self.ui.menuMenu.setTitle(_("Menu"))
+        self.ui.actionHelp.setText(_("Help"))
+        self.ui.actionAbout.setText(_("About"))
 
-        app.processEvents() #force ui update
+#        app.processEvents() #force ui update
 
 
 
@@ -762,18 +768,18 @@ class frmRecordWindow(QMainWindow):
 #        t=strftime("%d. %b. %Y %H:%M:%S", data.StartTime)
         t=strftime("%a. %x %X", data.StartTime)
 #        self.ui.lblStarttime.setText("Start: "+t)
-        self.ui.lblElapsedTime.setText("Elapsed time:")
+        self.ui.lblElapsedTime.setText(_("Elapsed time:"))
 #        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
         self.ui.bStop.setIcon(QIcon(data.app_path+"img/"+"krec2.png"))
-        self.ui.bStop.setText("Stop")
+        self.ui.bStop.setText(_("Stop"))
 
         if(records.AlarmIsSet==True): #alarm active
             m=str(data.AlarmMinute)
             if(len(m)==1): m="0"+m
 #            self.ui.lblAlarmTime.setText(str(data.AlarmHour)+":"+m+" or up to "+str(data.AlarmTimeWindow)+" minutes before that")
-            self.ui.lblAlarmTime.setText("Alarm time: "+strftime("%H:%M", records.AlarmTimeWindowStart_tuple)+" - "+strftime("%H:%M", records.AlarmTimeWindowEnd_tuple))
+            self.ui.lblAlarmTime.setText(_("Alarm time:")+" "+strftime("%H:%M", records.AlarmTimeWindowStart_tuple)+" - "+strftime("%H:%M", records.AlarmTimeWindowEnd_tuple))
         else: #Do only recording, no alarm
-            self.ui.lblAlarmTime.setText("Alarm time: (No Alarm set)")
+            self.ui.lblAlarmTime.setText(_("Alarm time: (No Alarm set)"))
 
 #        self.ui.lblNote.setText("Note: ")
         self.UpdateScreen()
@@ -793,7 +799,7 @@ class frmRecordWindow(QMainWindow):
             time_difference=t-data.StartTimeSec
             d=time.strftime("%Hh %Mm", time.gmtime(time_difference))
 #            self.ui.lblElapsedTime.setText("Elapsed time: "+d + " ("+str(records.Index)+" entries)")
-            self.ui.lblElapsedTime.setText("Elapsed time: "+d)
+            self.ui.lblElapsedTime.setText(_("Elapsed time:")+" "+d)
         else: self.UpdateScreenStop()
 
 #        self.ui.lblStatus2.setText("Status: "+data.Status)
@@ -815,7 +821,7 @@ class frmRecordWindow(QMainWindow):
 
 
     def UpdateScreenStop(self): ##(Class RecordWindow)
-        self.ui.bStop.setText("Close")
+        self.ui.bStop.setText(_("Close"))
 #        self.ui.lblStatus2.setText("Status: "+data.Status)
         self.ui.lblStatus2.setText(data.Status)
 
@@ -830,7 +836,7 @@ class frmRecordWindow(QMainWindow):
 
 
     def ZoomIn(self): ##(Class RecordWindow)
-        self.ui.lblStatus.setText("Zoom in...")
+        self.ui.lblStatus.setText(_("Zoom in..."))
         self.ui.lblStatus.show()
         app.processEvents() #force ui update
         Zoom(+1)
@@ -840,7 +846,7 @@ class frmRecordWindow(QMainWindow):
 
 
     def ZoomOut(self): ##(Class RecordWindow)
-        self.ui.lblStatus.setText("Zoom out...")
+        self.ui.lblStatus.setText(_("Zoom out..."))
         self.ui.lblStatus.show()
         app.processEvents() #force ui update
         Zoom(-1)
@@ -850,7 +856,7 @@ class frmRecordWindow(QMainWindow):
 
 
     def RaiseTrigger(self): ##(Class RecordWindow)
-        self.ui.lblStatus.setText("Raise trigger level...")
+        self.ui.lblStatus.setText(_("Raise trigger level..."))
         self.ui.lblStatus.show()
         app.processEvents() #force ui update
         MoveTrigger(+1)
@@ -864,7 +870,7 @@ class frmRecordWindow(QMainWindow):
 
 
     def LowerTrigger(self): ##(Class RecordWindow)
-        self.ui.lblStatus.setText("Lower trigger level...")
+        self.ui.lblStatus.setText(_("Lower trigger level..."))
         self.ui.lblStatus.show()
         app.processEvents() #force ui update
         MoveTrigger(-1)
@@ -902,7 +908,7 @@ class frmRecordWindow(QMainWindow):
 
 
     def EditNote(self): ##(Class RecordWindow)
-        r=QInputDialog.getText(None,  "Add Note",  "Add a note to this record:\n(leave empty for no note)",  QLineEdit.Normal,  records.Note)
+        r=QInputDialog.getText(None,  _("Note about this record"),  _("Add a note to this record\n(leave empty for no note):"),  QLineEdit.Normal,  records.Note)
         if(r[1]==True): #OK pressed
             records.Note=unicode(r[0])
 #            self.ui.lblNote.setText("Note: "+records.Note)
@@ -946,7 +952,6 @@ class frmViewWindow(QMainWindow):
         self.ui.CanvasWidget.setMinimumSize(QtCore.QSize(1000, data.GraphBitMapHeight)) #needed?
 
 
-
         QtCore.QObject.connect(self.ui.bRaiseTrigger, QtCore.SIGNAL("clicked()"), self.RaiseTrigger)
         QtCore.QObject.connect(self.ui.bLowerTrigger, QtCore.SIGNAL("clicked()"), self.LowerTrigger)
         QtCore.QObject.connect(self.ui.bZoomIn, QtCore.SIGNAL("clicked()"), self.ZoomIn)
@@ -995,6 +1000,7 @@ class frmViewWindow(QMainWindow):
             self.ui.bStatistics.setIcon(QIcon(data.app_path+"img/"+"klipper_dock.png"))
 
 
+        self.setWindowTitle("SleepAnalyser ("+_("View")+")")
 
 
     def UpdateScreen(self): ##(Class ViewWindow)
@@ -1011,7 +1017,7 @@ class frmViewWindow(QMainWindow):
 #        else: d=""
         self.ui.lblStart.setText(str(day))
 #        self.ui.lblEnd.setText(str(d1)+" (Duration: "+d+str(diff)+")")
-        self.ui.lblEnd.setText("Start: "+d0+", End: "+d1+", Duration: "+diff)
+        self.ui.lblEnd.setText(_("Start:")+" "+d0+", "+_("End:")+" "+d1+", "+_("Duration:")+" "+diff)
         self.ui.lblEnd.setText(d0+" - "+d1+"   ("+diff+")")
 
 #        self.ui.lblNote.setText("Note: "+records.Note)
@@ -1058,13 +1064,13 @@ class frmViewWindow(QMainWindow):
         self.Canvas.hide()
         self.StatisticsCanvas.hide()
 
-        self.ui.lblStatus.setText("Loading record...")
+        self.ui.lblStatus.setText(_("Loading record..."))
         self.ui.lblStatus.show()
         app.processEvents() #force ui update
 
         r=LoadRecord()
         if(r==1): #file too long
-            QtGui.QMessageBox.warning(self, 'Record too long!', "The record is too long. The end will be cut off!", QtGui.QMessageBox.Ok)
+            QtGui.QMessageBox.warning(self, _("Record too long!"), _("The record is too long. The end will be cut off!"), QtGui.QMessageBox.Ok)
         elif(r==2): #file does not exist
             self.OpenRecord()
             return
@@ -1078,20 +1084,20 @@ class frmViewWindow(QMainWindow):
 #            QtGui.QMessageBox.warning(self, 'File version too old!', "Can not load record \n"+data.logfilename+"\nas it got created from SleepAnalyser version <1.6 and is not compatible with the current SleepAnalyser version.", QtGui.QMessageBox.Ok)
 #        LoadFileList()
 
-        self.ui.lblStatus.setText("Processessing data...")
+        self.ui.lblStatus.setText(_("Processessing data..."))
         app.processEvents() #force ui update
         ProcessData(True, True)
 
-        self.ui.lblStatus.setText("Rendering data...")
+        self.ui.lblStatus.setText(_("Rendering data..."))
         app.processEvents() #force ui update
 
         FilterData()
 
-        self.ui.lblStatus.setText("Generating statistic...")
+        self.ui.lblStatus.setText(_("Generating statistic..."))
         app.processEvents() #force ui update
 
         GenerateStatisticData()
-        data.Xscale=1 #default zoom level
+#        data.Xscale=1 #default zoom level
         data.Xscale=2
 #        data.GraphStart=max(records.LastIndex-data.arrXscale[data.Xscale]*775, 0)
 
@@ -1133,7 +1139,7 @@ class frmViewWindow(QMainWindow):
     ##
     ###########################################################################
     def ZoomIn(self): ##(Class ViewWindow)
-        self.ui.lblStatus.setText("Zoom in...")
+        self.ui.lblStatus.setText(_("Zoom in..."))
         self.ui.lblStatus.show()
         app.processEvents() #force ui update
         Zoom(+1)
@@ -1162,7 +1168,7 @@ class frmViewWindow(QMainWindow):
     ##
     ###########################################################################
     def ZoomOut(self): ##(Class ViewWindow)
-        self.ui.lblStatus.setText("Zoom out...")
+        self.ui.lblStatus.setText(_("Zoom out..."))
         self.ui.lblStatus.show()
         app.processEvents() #force ui update
         Zoom(-1)
@@ -1183,7 +1189,7 @@ class frmViewWindow(QMainWindow):
     ##
     ###########################################################################
     def RaiseTrigger(self): ##(Class ViewWindow)
-        self.ui.lblStatus.setText("Raise trigger level...")
+        self.ui.lblStatus.setText(_("Raise trigger level..."))
         self.ui.lblStatus.show()
         MoveTrigger(+1)
         app.processEvents() #force ui update
@@ -1200,7 +1206,7 @@ class frmViewWindow(QMainWindow):
     ##
     ###########################################################################
     def LowerTrigger(self): ##(Class ViewWindow)
-        self.ui.lblStatus.setText("Lower trigger level...")
+        self.ui.lblStatus.setText(_("Lower trigger level..."))
         self.ui.lblStatus.show()
         MoveTrigger(-1)
         app.processEvents() #force ui update
@@ -1222,7 +1228,7 @@ class frmViewWindow(QMainWindow):
     def DeleteLogFile(self): ##(Class ViewWindow)
         self.ui.lblStatus.setText("Delete file...")
         self.ui.lblStatus.show()
-        reply = QtGui.QMessageBox.question(self, 'Delete Record?', "Are you sure you want to delete this record:\n"+data.logfilename, QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+        reply = QtGui.QMessageBox.question(self, _("Delete Record?"), _("Are you sure you want to delete this record:")+"\n"+data.logfilename, QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
         if reply == QtGui.QMessageBox.Yes:
             print "Delete logfile: "+data.logfilename
             os.remove(data.logfolder+data.logfilename)
@@ -1260,7 +1266,7 @@ class frmViewWindow(QMainWindow):
         self.ui.lblNote.setText("")
         self.Canvas.hide()
         self.StatisticsCanvas.hide()
-        self.ui.lblStatus.setText("Opening file dialog...")
+        self.ui.lblStatus.setText(_("Opening file dialog..."))
         self.ui.lblStatus.show()
 
 
@@ -1285,7 +1291,7 @@ class frmViewWindow(QMainWindow):
     def ShowFileDialog(self): ##(Class ViewWindow)
         data.logfolder=string.replace(data.logfolder, "~",  data.homedir) #workaround
         if(data.debug==1): print "Open file dialog in:",  data.logfolder
-        tmp= QFileDialog.getOpenFileName(None,"Open SleepAnalyser Log File", data.logfolder, "Log Files (*.csv)")
+        tmp= QFileDialog.getOpenFileName(None,_("Open SleepAnalyser record"), data.logfolder, _("Record Files")+" (*.csv)")
         print "Selected file:",  tmp
         return tmp
 
@@ -1310,7 +1316,7 @@ class frmViewWindow(QMainWindow):
     ##
     ###########################################################################
     def EditNote(self): ##(Class ViewWindow)
-        r=QInputDialog.getText(None,  "Edit Note",  "Add a note to this record:\n(leave empty for no note)",  QLineEdit.Normal,  records.Note)
+        r=QInputDialog.getText(None,  _("Note about this record"),  _("Add a note to this record\n(leave empty for no note):"),  QLineEdit.Normal,  records.Note)
         if(r[1]==True): #OK pressed
             tmp=r[0]
             tmp=unicode(tmp)
@@ -1344,12 +1350,12 @@ class frmViewWindow(QMainWindow):
 
     def Export(self): ##(Class ViewWindow)
         filename=string.replace(data.logfilename, ".csv",  "")
-        tmp=QFileDialog.getSaveFileName(None,"Export graph as", data.defaultlogfolder+filename, "PNG-Image (*.png)") #;;JPEG-Image (*.jpg)
+        tmp=QFileDialog.getSaveFileName(None,_("Export graph as"), data.defaultlogfolder+filename, _("PNG-Image")+" (*.png)") #;;JPEG-Image (*.jpg)
         if(tmp!=""):
             print "Export graph as :",  tmp
             r=data.GraphBitMap.save(tmp,  "png",  -1)
             if(r==True): print "Export was successful"
-            else: QtGui.QMessageBox.warning(self, 'Could not export file', "Failed to save graph as file\n"+tmp, QtGui.QMessageBox.Ok)
+            else: QtGui.QMessageBox.warning(self, _("Could not export file"), _("Failed to save graph as image:")+"\n"+tmp, QtGui.QMessageBox.Ok)
 #        print "beep2"""
 #        self.show()
 #        HelpWindow.show()
@@ -1378,12 +1384,15 @@ class frmHelpWindow(QMainWindow):
         self.ui = Ui_HelpWindow()
         self.ui.setupUi(self)
 
+#        TODO: support multilingual info file
         file = open(data.app_path+"Info.htm", 'r')
         txt=""
         for line in file: txt=txt+line+"\n"
         file.close()
         self.ui.textBrowser.setHtml(txt)
 
+        self.setWindowTitle("SleepAnalyser ("+_("Help")+")")
+
 
     def closeEvent(self, event): ##(Class HelpWindow)
         self.close()
@@ -1407,7 +1416,8 @@ class frmConfigWindow(QMainWindow):
 
         QtCore.QObject.connect(self.ui.bEditUserName, QtCore.SIGNAL("clicked()"), self.EditUserName)
         QtCore.QObject.connect(self.ui.SlrDelayStart,SIGNAL("valueChanged(int)"),self.DelaySliderMoved)
-        QtCore.QObject.connect(self.ui.SlrYscale,SIGNAL("valueChanged(int)"),self.YscaleSliderMoved)
+        QtCore.QObject.connect(self.ui.SlrYscale_Movement,SIGNAL("valueChanged(int)"),self.YscaleSliderMoved_Movement)
+        QtCore.QObject.connect(self.ui.SlrYscale_Sleep,SIGNAL("valueChanged(int)"),self.YscaleSliderMoved_Sleep)
 
 
         QtCore.QObject.connect(self.ui.bOK, QtCore.SIGNAL("clicked()"), self.OK)
@@ -1417,13 +1427,27 @@ class frmConfigWindow(QMainWindow):
         #Add styles to buttons
         self.ui.bEditUserName.setStyleSheet(data.UIStyle)
         self.ui.SlrDelayStart.setStyleSheet(data.UIStyle)
-        self.ui.SlrYscale.setStyleSheet(data.UIStyle)
+        self.ui.SlrYscale_Movement.setStyleSheet(data.UIStyle)
 
         #Add styles to tick boxes
         self.ui.cOfflineMode.setStyleSheet(data.UIStyle)
         self.ui.cStopAfterAlarm.setStyleSheet(data.UIStyle)
         self.ui.cSilentProfile.setStyleSheet(data.UIStyle)
 
+        self.setWindowTitle("SleepAnalyser ("+_("Settings")+")")
+        self.ui.cOfflineMode.setText(_("Change to Offline Mode while recording"))
+        self.ui.cSilentProfile.setText(_("Change to Silent Profile while recording"))
+        self.ui.cStopAfterAlarm.setText(_("Stop recording after alarm occured"))
+        self.ui.lblUser.setText(_("User name:"))
+        self.ui.bEditUserName.setText(_("Change"))
+        self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_General), _("General"))
+        self.ui.lblDelayStart.setText(_("Start delay:"))
+        self.ui.lblYscale_Movement.setText(_("Y scaling movement bars (yellow):"))
+        self.ui.lblYscale_Sleep.setText(_("Y scaling sleep graph (blue):"))
+        self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_Advanced), _("Advanced"))
+        self.ui.lblMore.setText(_("More settings can be changed at your own risk in the file\n~/.SleepAnalyer/SleepAnalyser.conf."))
+        self.ui.tabWidget.setTabText(self.ui.tabWidget.indexOf(self.ui.tab_More), _("More"))
+        self.ui.bOK.setText(_("OK"))
 
 
     ###########################################################################
@@ -1436,11 +1460,16 @@ class frmConfigWindow(QMainWindow):
         else: self.ui.cSilentProfile.setChecked(False)
         if(data.StopAfterAlarm==True): self.ui.cStopAfterAlarm.setChecked(True)
         else: self.ui.cStopAfterAlarm.setChecked(False)
-        self.ui.lblUser.setText("User name: "+data.user)
-        self.ui.lblDelayStart.setText("Start delay: "+str(data.DelayStartTime)+" sec")
+        self.ui.lblUser.setText(_("User name:")+" "+data.user)
+        self.ui.lblDelayStart.setText(_("Start delay:")+" "+str(data.DelayStartTime)+" seconds")
         self.ui.SlrDelayStart.setValue(int(data.DelayStartTime))
-        self.ui.lblYscale.setText("Y scaling: "+str(data.Yscale))
-        self.ui.SlrYscale.setValue(int(data.Yscale))
+
+        self.ui.lblYscale_Movement.setText(_("Y scaling movement (yellow):")+" "+str(data.Yscale))
+        self.ui.SlrYscale_Movement.setValue(int(data.Yscale))
+
+
+        self.ui.lblYscale_Sleep.setText(_("Y scaling sleep pattern (blue):")+" "+str(data.filterScale))
+        self.ui.SlrYscale_Sleep.setValue(int(data.filterScale))
 
 
 
@@ -1493,6 +1522,7 @@ class frmConfigWindow(QMainWindow):
         config.set('main', 'user', str(data.user.encode( "utf-8" )))
         config.set('main', 'DelayStartTime', str(data.DelayStartTime))
         config.set('main', 'Yscale', str(data.Yscale))
+        config.set('main', 'filterScale', str(data.filterScale))
 
 
 
@@ -1501,7 +1531,7 @@ class frmConfigWindow(QMainWindow):
     ###########################################################################
     def EditUserName(self): ##(Class ConfigWindow)
         EditUserName()
-        self.ui.lblUser.setText("User name: "+data.user)
+        self.ui.lblUser.setText(_("User name:")+" "+data.user)
 
 
     ###########################################################################
@@ -1510,19 +1540,25 @@ class frmConfigWindow(QMainWindow):
     def DelaySliderMoved(self): ##(Class ConfigWindow)
         x=self.ui.SlrDelayStart.value()
         data.DelayStartTime=x
-        self.ui.lblDelayStart.setText("Start delay: "+str(data.DelayStartTime)+" sec")
+        self.ui.lblDelayStart.setText(_("Start delay:")+" "+str(data.DelayStartTime)+" "+_("sec"))
 
 
     ###########################################################################
     ##
     ###########################################################################
-    def YscaleSliderMoved(self): ##(Class ConfigWindow)
-        x=self.ui.SlrYscale.value()
+    def YscaleSliderMoved_Movement(self): ##(Class ConfigWindow)
+        x=self.ui.SlrYscale_Movement.value()
         data.Yscale=int(x)
-        self.ui.lblYscale.setText("Y scaling: "+str(data.Yscale))
-
+        self.ui.lblYscale_Movement.setText(_("Y scaling movement (yellow):")+" "+str(data.Yscale))
 
 
+    ###########################################################################
+    ##
+    ###########################################################################
+    def YscaleSliderMoved_Sleep(self): ##(Class ConfigWindow)
+        x=self.ui.SlrYscale_Sleep.value()
+        data.filterScale=int(x)
+        self.ui.lblYscale_Sleep.setText(_("Y scaling sleep graph (blue):")+" "+str(data.filterScale))
 
 
 
@@ -1545,7 +1581,7 @@ class frmDateWindow(QMainWindow):
 
         self.ui.cal.showToday()
 
-
+        self.setWindowTitle("SleepAnalyser ("+_("Select date)")+")")
 
 
     ###########################################################################
@@ -1561,7 +1597,10 @@ class frmDateWindow(QMainWindow):
 
         amount=len(arr)-1
 
-        self.ui.lblResult.setText("Found "+str(amount)+" Records for this date.")
+#TODO: visualise dates with records
+
+        txt=string.replace(_("Found % Record(s) for this date."),"%", str(amount))
+        self.ui.lblResult.setText(txt)
         if(amount>0):
             self.ui.bOpen.setEnabled(True)
             data.LogFileSelectedDate=arr[0] #select first file of that date for opening
@@ -1602,6 +1641,8 @@ class frmAdditionalInfoWindow(QMainWindow):
         self.ui = Ui_AdditionalInfoWindow()
         self.ui.setupUi(self)
 
+        self.setWindowTitle("SleepAnalyser ("+_("Record Info\'s)")+")")
+
 
     ###########################################################################
     ##
@@ -1630,31 +1671,32 @@ class frmAdditionalInfoWindow(QMainWindow):
                 a1=strftime("%H:%M:%S", records.AlarmTimeWindowEnd_tuple) #on same day, only show date once
             else:
                 a1=strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTimeWindowEnd_tuple)
-            alarm="<b>Alarm Time Window:</b> "+a0+" - "+a1 + "<br>"
+            alarm="<b>"+_("Alarm Time Window:")+"</b> "+a0+" - "+a1 + "<br>"
             if(records.AlarmTime_seconds!=-1): #alarm was set
                 if(records.EndTime_seconds>=records.AlarmTime_seconds-60): #alarm got set off during recording (-60 is workaround)
-                    alarm=alarm+"<b>Alarm:</b> Alarm went off on: "+strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTime_tuple)+"<br>"
+                    alarm=alarm+"<b>"+_("Alarm:")+"</b> "+_("Alarm went off on:")+" "+strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTime_tuple)+"<br>"
                     if(records.AlarmTimeWindowEnd_seconds<=records.AlarmTime_seconds):
-                        alarm=alarm+"<b>Alarm reason:</b> End of alarm time window<br>"
+                        alarm=alarm+"<b>"+_("Alarm reason:")+"</b> "+_("End of alarm time window")+"<br>"
                     else:
-                        alarm=alarm+"<b>Alarm reason:</b> Movements over trigger level<br>"
+                        alarm=alarm+"<b>"+_("Alarm reason:")+"</b> "+_("Movements over trigger level")+"<br>"
                 else:
-                    alarm=alarm+"<b>Alarm:</b> Alarm never went off<br>"
+                    alarm=alarm+"<b>"+_("Alarm:")+"</b> "+_("Alarm never went off")+"<br>"
             else:
-                alarm=alarm+"<b>Alarm:</b> Alarm never went off<br>"
+                alarm=alarm+"<b>"+_("Alarm:")+"</b> "+_("Alarm never went off")+"<br>"
         else:
-            alarm="<b>Alarm:</b> No alarm was set<br>"
+            alarm="<b>"+_("Alarm:")+"</b> "+_("No alarm was set")+"<br>"
 
-        txt= "<b>File:</b> "+str(shortfolder)+str(data.logfilename+"<br>") + \
-        "<b>User:</b> "+records.User +"<br>" + \
-        "<b>Time:</b> "+d0+" - "+d1+"<br>" + \
-        "<b>Duration:</b> "+ diff+"<br>" + \
-        "<b>Record entries:</b> "+str(records.Index)+" (1 per "+str(int(records.Sampling_interval*records.Value_smoothing/1000))+" seconds)<br>" +\
-        "<b>Record version:</b> "+str(records.SWversion) + "<br>" + \
-        "<b>Note:</b> "+records.Note+"<br>" +\
+        txt= "<b>"+_("File:")+"</b> "+str(shortfolder)+str(data.logfilename+"<br>") + \
+        "<b>"+_("Date/Time:")+"</b> "+d0+" - "+d1+"<br>" + \
+        "<b>"+_("Duration:")+"</b> "+ diff+"<br>" + \
+        "<b>"+_("Record entries:")+"</b> "+str(records.Index)+" (1/"+str(int(records.Sampling_interval*records.Value_smoothing/1000))+" "+_("seconds")+")<br>" +\
+        "<b>"+_("Record version:")+"</b> "+str(records.SWversion) + "<br>" + \
         alarm +\
-        "<b>Trigger level:</b> "+str(records.Trigger) + "<br>" + \
-        "<b>Condition of record:</b> "+str(records.status)+"<br><br>"
+        "<b>"+_("Trigger level:")+"</b> "+str(records.Trigger) + "<br>" + \
+        "<b>"+_("Condition of record:")+"</b> "+str(records.status)+"<br><br>"
+#        "<b>"+_("User:")+"</b> "+str(records.User) +"<br>" + \ ##Disabled due charset errors
+#        "<b>"+_("Note:")+"</b> "+str(records.Note)+"<br>" +\ ##Disabled due charset errors
+
 
 
 #        t_total=(records.EndTime_seconds-records.StartTime_seconds)
@@ -1666,17 +1708,17 @@ class frmAdditionalInfoWindow(QMainWindow):
 ##        pd=records.arrStatData[3][0]*100/t_total
 #        pl=100-pa-pb-pc
 
-        txt=txt+"<b>Statistics:</b><table>\n" + \
-                "<tr><td><b>Sleep phase: </b></td>   <td><b>Total time: </b></td>                                     <td><b>Longest time:</b></td>                                    <td><b>Count: </b></td>                     <td colspan=2><b>Time percent:</b></td>\n" + \
-                "<tr><td><b>Awake:</b></td>         <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[3][0]))+"</td>    <td>-</td>    <td>-</td>    <td>"+str(records.arrStatData[3][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State4.png"+"\" width="+str(records.arrStatData[3][3]*2)+" height=25</td></tr>\n" + \
-                "<tr><td><b>Light:</b></td>         <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[2][0]))+"</td>    <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[2][2]))+"</td>    <td>"+str(records.arrStatData[2][1])+"</td>    <td>"+str(records.arrStatData[2][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State3.png"+"\" width="+str(records.arrStatData[2][3]*2)+" height=25</td></tr>\n" + \
-                "<tr><td><b>Middle:</b></td>        <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[1][0]))+"</td>    <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[1][2]))+"</td>    <td>"+str(records.arrStatData[1][1])+"</td>    <td>"+str(records.arrStatData[1][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State2.png"+"\" width="+str(records.arrStatData[1][3]*2)+" height=25</td></tr>\n" + \
-                "<tr><td><b>Deep:</b></td>          <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[0][0]))+"</td>    <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[0][2]))+"</td>    <td>"+str(records.arrStatData[0][1])+"</td>    <td>"+str(records.arrStatData[0][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State1.png"+"\" width="+str(records.arrStatData[0][3]*2)+" height=25</td></tr>\n" + \
+        txt=txt+"<b>"+_("Statistics:")+"</b><table>\n" + \
+                "<tr><td><b>"+_("Sleep phase:")+" </b></td>   <td><b>"+_("Total time:")+" </b></td>                                     <td><b>"+_("Longest time:")+"</b></td>                                    <td><b>"+_("Count:")+" </b></td>                     <td colspan=2><b>"+_("Time percent:")+"</b></td>\n" + \
+                "<tr><td><b>"+_("Awake:")+"</b></td>         <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[3][0]))+"</td>    <td>-</td>    <td>-</td>    <td>"+str(records.arrStatData[3][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State4.png"+"\" width="+str(records.arrStatData[3][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td><b>"+_("Light:")+"</b></td>         <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[2][0]))+"</td>    <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[2][2]))+"</td>    <td>"+str(records.arrStatData[2][1])+"</td>    <td>"+str(records.arrStatData[2][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State3.png"+"\" width="+str(records.arrStatData[2][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td><b>"+_("Middle:")+"</b></td>        <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[1][0]))+"</td>    <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[1][2]))+"</td>    <td>"+str(records.arrStatData[1][1])+"</td>    <td>"+str(records.arrStatData[1][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State2.png"+"\" width="+str(records.arrStatData[1][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td><b>"+_("Deep:")+"</b></td>          <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[0][0]))+"</td>    <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[0][2]))+"</td>    <td>"+str(records.arrStatData[0][1])+"</td>    <td>"+str(records.arrStatData[0][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State1.png"+"\" width="+str(records.arrStatData[0][3]*2)+" height=25</td></tr>\n" + \
               "</table><br><br>\n"
 
-        txt=txt+"<b>Sampling interval:</b> "+str(records.Sampling_interval) + " ms<br>" + \
-        "<b>Sampling smoothing:</b> "+str(records.Sample_smoothing) + "<br>" + \
-        "<b>Value smoothing:</b> "+str(records.Value_smoothing)
+        txt=txt+"<b>"+_("Sampling interval:")+"</b> "+str(records.Sampling_interval) + " ms<br>" + \
+        "<b>"+_("Sampling smoothing:")+"</b> "+str(records.Sample_smoothing) + "<br>" + \
+        "<b>"+_("Value smoothing:")+"</b> "+str(records.Value_smoothing)
 
         self.ui.textBrowser.setHtml("<html><body>"+txt+"</html></body>")
 
@@ -1716,6 +1758,15 @@ class frmAlarmTimeWindow(QMainWindow):
         if(data.app_path!="./"): #only needed if not started in app path
             self.ui.bSetAlarm.setIcon(QIcon(data.app_path+"img/"+"SleepAnalyser.png"))
 
+        self.setWindowTitle("SleepAnalyser ("+_("Set alarm")+")")
+        txt=_("The Alarm will go off sometimes during the set time window (as soon as your movement is over the trigger level), but latest at the set alarm time.")
+        self.ui.lblNote.setText(txt)
+        self.ui.bSetAlarm.setText(_("Set alarm"))
+        self.ui.label_7.setText(_("Alarm Time:"))
+        self.ui.label_9.setText(_("Time Window:"))
+        self.ui.label_8.setText(_("Hour:"))
+        self.ui.label_10.setText(_("Minutes:"))
+        self.ui.label_11.setText(_("Minutes:"))
 
 
     ###########################################################################
@@ -1729,8 +1780,7 @@ class frmAlarmTimeWindow(QMainWindow):
         self.ui.lstAlarmHour.setCurrentRow(int(data.AlarmHour))
         self.ui.lstAlarmMinute.setCurrentRow(int(data.AlarmMinute)/5)
         self.ui.lstAlarmTimeWindow.setCurrentRow(int(data.AlarmTimeWindow)/5-1)
-        s="The Alarm will go off sometimes during the set time window (as soon as your movement is over the trigger level), but latest at the set alarm time."
-        self.ui.lblNote.setText(s)
+
 
 
 
@@ -1826,6 +1876,12 @@ class frmAskForKeepWindow(QMainWindow):
             self.ui.bstop_removeRecord.setIcon(QIcon(data.app_path+"img/"+"edittrash.png"))
             self.ui.bcontinue.setIcon(QIcon(data.app_path+"img/"+"krec.png"))
 
+        self.setWindowTitle("SleepAnalyser ("+_("Recording")+")")
+        self.ui.bcontinue.setText(_("Continue recording"))
+        self.ui.bstop_keepRecord.setText(_("Stop recording and keep the record"))
+        self.ui.bstop_removeRecord.setText(_("Stop recording and delete the record"))
+
+
 
     ###########################################################################
     ##
